var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
import { SWR } from "swrev";
import { ref, watch, getCurrentInstance, onUnmounted, computed, watchEffect } from "vue";
class VSWR extends SWR {
  query(key, options) {
    const data = ref();
    const error = ref();
    const unsubscribe = watch(() => this.resolveKey(key), (_values, _oldValues, onInvalidate) => {
      const onData = (d) => {
        error.value = void 0;
        data.value = d;
      };
      const onError = (e) => {
        error.value = e;
      };
      const { unsubscribe: unsubscribe2 } = this.subscribe(key, onData, onError, __spreadValues({
        loadInitialCache: true
      }, options));
      onInvalidate(() => unsubscribe2());
    }, { immediate: true });
    if (getCurrentInstance())
      onUnmounted(() => stop());
    const mutate2 = (value, ops) => {
      return this.mutate(this.resolveKey(key), value, __spreadValues({
        revalidateOptions: options
      }, ops));
    };
    const revalidate2 = (ops) => {
      return this.revalidate(this.resolveKey(key), __spreadValues(__spreadValues({}, options), ops));
    };
    const clear2 = (ops) => {
      return this.clear(this.resolveKey(key), ops);
    };
    const isLoading = computed(() => data.value === void 0 && error.value === void 0);
    const isValid = computed(() => data.value !== void 0 && error.value === void 0);
    const loading = () => {
      let unsubscribe2 = void 0;
      return new Promise((resolve, reject) => {
        unsubscribe2 = watchEffect(() => {
          if (isLoading.value)
            return;
          else if (error.value !== void 0)
            reject(error);
          else
            resolve(data);
        });
      }).finally(() => unsubscribe2 == null ? void 0 : unsubscribe2());
    };
    return { data, error, mutate: mutate2, revalidate: revalidate2, clear: clear2, unsubscribe, isLoading, isValid, loading };
  }
  async querySuspense(key, options) {
    const { loading, error, mutate: mutate2, revalidate: revalidate2, clear: clear2, unsubscribe } = this.query(key, options);
    watch(error, (e) => {
      unsubscribe();
      if (e)
        throw e;
    });
    return { data: await loading(), mutate: mutate2, revalidate: revalidate2, clear: clear2, unsubscribe };
  }
}
const createSWR = (options) => new VSWR(options);
let swr = createSWR();
const createDefaultSWR = (options) => {
  swr = createSWR(options);
  return swr;
};
const subscribeData = (key, onData) => {
  return swr.subscribeData(key, onData);
};
const subscribeErrors = (key, onError) => {
  return swr.subscribeErrors(key, onError);
};
const get = (key) => {
  return swr.get(key);
};
const getWait = (key) => {
  return swr.getWait(key);
};
const subscribe = (key, onData, onError, options) => {
  return swr.subscribe(key, onData, onError, options);
};
const query = (key, options) => {
  return swr.query(key, options);
};
const querySuspense = (key, options) => {
  return swr.querySuspense(key, options);
};
const mutate = (key, value, options) => {
  return swr.mutate(key, value, options);
};
const revalidate = (key, options) => {
  return swr.revalidate(key, options);
};
const clear = (keys, options) => {
  return swr.clear(keys, options);
};
export { VSWR, clear, createDefaultSWR, createSWR, get, getWait, mutate, query, querySuspense, revalidate, subscribe, subscribeData, subscribeErrors, swr };
